@@ -1,7 +1,9 @@
 mod group;
 mod op;
+mod seek;
 mod state;
 
 pub use group::MemoryGroup;
 pub use op::MemoryOp;
+pub use seek::MemorySeek;
 pub use state::MemoryState;
